package
Version:
v1.9.1
Opens a new window with list of versions in this module.
Published: Feb 20, 2025
License: Unlicense
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func GetAsBytes(prf ...P) (b [][]byte)
GetAsBytes todo wat is dis?
B returns the index.P as a byte.
I returns the index.P as an int (for use with the KeySizes.
Key writes a key with the P prefix byte and an arbitrary list of
keys.Element.
type T struct {
Val []byte
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.